@@ -26,10 +26,11 @@
 * ja:ヘッダ解析関数                                                           *
 *                                                                             *
 ******************************************************************************/
-static void
+static gboolean
 dw32_header_resource_directory (Dw32Info    *info,
                                 const gint   index,
-                                const gchar *name)
+                                const gchar *name,
+                                const gint   depth)
 {
   gint i, count;
   guint32 address;
@@ -43,17 +44,19 @@ dw32_header_resource_directory (Dw32Info    *info,
                                      {2, "Number of ID Entries"},
                                      {0, NULL}};
 
+  if (depth > 2)
+    return FALSE;
   g_fprintf (stderr, "%08x/%08"G_GSIZE_MODIFIER"x Resource %s\n",
                                                     index, info->size, name);
   ird = (ImageResourceDirectory *)(info->image + index);
   irde = (ImageResourceDirectoryEntry *)(ird + 1);
   if (index < 0 || info->size <= index + sizeof (ImageResourceDirectory))
-    return;
+    return FALSE;
   count = ird_get_number_of_named_entries (ird)
                                         + ird_get_number_of_id_entries (ird);
   if (info->size <= index + sizeof (ImageResourceDirectory)
                                 + count * sizeof (ImageResourceDirectoryEntry))
-    return;
+    return FALSE;
   info->separate[index] = g_strdup ("Resource Directory Table");
   dw32_data_make_struct (info, index, dataird, -1);
   address = pe_ioh_get_data_directory_virtual_address (info->image,
@@ -99,9 +102,10 @@ dw32_header_resource_directory (Dw32Info    *info,
         }
       if (irde_get_offset_to_data (irde) & 0x80000000)
         {
-          dw32_header_resource_directory (info,
+          if (!dw32_header_resource_directory (info,
                     address + (irde_get_offset_to_data (irde) & 0x7fffffff),
-                                                                    new_name);
+                                                        new_name, depth + 1))
+            return FALSE;
           datairde[1].name = "Subdirectory RVA";
         }
       else
@@ -135,6 +139,7 @@ dw32_header_resource_directory (Dw32Info    *info,
       dw32_data_make_struct (info, offset, datairde, -1);
       irde++;
     }
+  return TRUE;
 }
 
 
@@ -271,10 +276,10 @@ dw32_header_parse (Dw32Info *info)
           for (i = 0; i < ied_get_number_of_names (ied); i++)
             dw32_data_make_string (info, GUINT32_FROM_LE (names[i]), -1);
         }
+      for (i = 0; i < info->size; i++)
+        if (info->status[i] == DW32_STAT_DATA)
+          info->status[i] = DW32_STAT_EXPORT;
     }
-  for (i = 0; i < info->size; i++)
-    if (info->status[i] == DW32_STAT_DATA)
-      info->status[i] = DW32_STAT_EXPORT;
   /* ja:インポートテーブル */
   if (pe_ioh_get_data_directory_size (info->image,
                                             PEIMAGE_DIRECTORY_ENTRY_IMPORT))
@@ -386,20 +391,22 @@ dw32_header_parse (Dw32Info *info)
       if (address < info->size)
         info->separate[address] = g_strdup ("Import Table (NULL)");
       dw32_data_make_struct (info, address, dataiid, -1);
+      for (i = 0; i < info->size; i++)
+        if (info->status[i] == DW32_STAT_DATA)
+          info->status[i] = DW32_STAT_IMPORT;
     }
-  for (i = 0; i < info->size; i++)
-    if (info->status[i] == DW32_STAT_DATA)
-      info->status[i] = DW32_STAT_IMPORT;
   /* ja:リソーステーブル */
   g_fprintf (stderr, "Resource Analyse\n");
   if (pe_ioh_get_data_directory_size (info->image,
                                             PEIMAGE_DIRECTORY_ENTRY_RESOURCE))
-    dw32_header_resource_directory (info,
+    {
+      dw32_header_resource_directory (info,
                         pe_ioh_get_data_directory_virtual_address (info->image,
-                                        PEIMAGE_DIRECTORY_ENTRY_RESOURCE), "");
-  for (i = 0; i < info->size; i++)
-    if (info->status[i] == DW32_STAT_DATA)
-      info->status[i] = DW32_STAT_RESOURCE;
+                                    PEIMAGE_DIRECTORY_ENTRY_RESOURCE), "", 0);
+      for (i = 0; i < info->size; i++)
+        if (info->status[i] == DW32_STAT_DATA)
+          info->status[i] = DW32_STAT_RESOURCE;
+    }
   /* ja:再配置 */
   if (pe_ioh_get_data_directory_size (info->image,
                                             PEIMAGE_DIRECTORY_ENTRY_BASERELOC))
@@ -429,9 +436,9 @@ dw32_header_parse (Dw32Info *info)
                     ibr_get_size_of_block (ibr) - sizeof (guint32) * 2, -1);
           index += ibr_get_size_of_block (ibr);
         }
+      for (i = 0; i < info->size; i++)
+        if (info->status[i] == DW32_STAT_DATA)
+          info->status[i] = DW32_STAT_RELOC;
     }
-  for (i = 0; i < info->size; i++)
-    if (info->status[i] == DW32_STAT_DATA)
-      info->status[i] = DW32_STAT_RELOC;
   return TRUE;
 }
