@@ -1,6 +1,6 @@
 /*
     opcode
-    copyright (c) 1998-2011 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2012 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -628,7 +628,7 @@ opcode_extend (const guint8   *image,
                                 mnemonic[code - 0x60], m.regop_s, m.regmem_s);
           }
           return TRUE;
-        case 0x6e: /* cvtpd2dq/movd/movq */
+        case 0x6e: /* movd/movq */
         case 0x7e:
           {
             ModRM m;
@@ -646,6 +646,7 @@ opcode_extend (const guint8   *image,
               g_sprintf (op->mnemonic, "%s %s,%s",
                         prep == 0xf3 ? "movq" : "movd", m.regmem_s, m.regop_s);
           }
+          return TRUE;
         case 0x6f: /* movdqa/movdqu/movq */
         case 0x7f:
           {
@@ -997,6 +998,7 @@ opcode_extend (const guint8   *image,
                                     m.regop_s, m.regmem_s, image[op->index]);
             op->index++;
           }
+          return TRUE;
         case 0xc5: /* pextrw */
           {
             ModRM m;
@@ -1009,6 +1011,7 @@ opcode_extend (const guint8   *image,
                                     m.regop_s, m.regmem_s, image[op->index]);
             op->index++;
           }
+          return TRUE;
         case 0xc7: /* cmpxchg8b */
           {
             ModRM m;
@@ -1021,6 +1024,7 @@ opcode_extend (const guint8   *image,
             g_sprintf (op->mnemonic, "cmpxchg8b %s", m.regmem_s);
             op->index++;
           }
+          return TRUE;
         case 0xc8: case 0xc9: case 0xca: case 0xcb: /* bswap */
         case 0xcc: case 0xcd: case 0xce: case 0xcf:
           g_sprintf (op->mnemonic, "bswap %s", regname[2][code & 7]);
@@ -1351,10 +1355,10 @@ opcode_parse (const guint8  *image,
                                             regname[pope ? 1 : 2][code & 7]);
           }
           return TRUE;
-        case 0x60: /* pusha */
+        case 0x60: /* pusha/pushad */
           g_strcpy (op->mnemonic, pope ? "pusha" : "pushad");
           return TRUE;
-        case 0x61: /* popa */
+        case 0x61: /* popa/popad */
           g_strcpy (op->mnemonic, pope ? "popa" : "popad");
           return TRUE;
         case 0x62: /* bound */
@@ -1597,10 +1601,10 @@ opcode_parse (const guint8  *image,
         case 0x98: /* cbw/cwde */
           g_strcpy (op->mnemonic, pope ? "cbw" : "cwde");
           return TRUE;
-        case 0x99: /* cbw/cwde */
+        case 0x99: /* cwd/cdq */
           g_strcpy (op->mnemonic, pope ? "cwd" : "cdq");
           return TRUE;
-        case 0x9a: /* call */
+        case 0x9a: /* call/callf */
           if (pope)
             {
               if (op->index + 4 >= size)
@@ -1624,10 +1628,10 @@ opcode_parse (const guint8  *image,
         case 0x9b: /* wait */
           g_strcpy (op->mnemonic, "wait");
           return TRUE;
-        case 0x9c: /* pushf */
+        case 0x9c: /* pushf/pushfd */
           g_strcpy (op->mnemonic, pope ? "pushf" : "pushfd");
           return TRUE;
-        case 0x9d: /* popf */
+        case 0x9d: /* popf/popfd */
           g_strcpy (op->mnemonic, pope ? "popf" : "popfd");
           return TRUE;
         case 0x9e: /* sahf */
@@ -1921,7 +1925,7 @@ opcode_parse (const guint8  *image,
         case 0xd7: /* xlat */
           g_strcpy (op->mnemonic, "xlat");
           return TRUE;
-        case 0xd8:
+        case 0xd8: /* fadd/fmul/fcom/fcomp/fsub/fsubr/fdiv/fdivr */
           {
             ModRM m;
             const gchar *mnemonic[] = {"fadd", "fmul",  "fcom", "fcomp",
@@ -1936,7 +1940,11 @@ opcode_parse (const guint8  *image,
                                                 mnemonic[m.regop], m.regmem);
           }
           return TRUE;
-        case 0xd9:
+        case 0xd9: /* fld/fst/fstp/fldenv/fldcw/fnstenv/fnstcw
+                      fxch/fnop/fchs/fabs/ftst/fxam
+                      fld1/fldl2t/fldl2e/fldpi/fldlg2/fldln2/fldz
+                      f2xm1/fyl2x/fptan/fpatan/fxtract/fprem1/fdecstp/fincstp
+                      fprem/fyl2xp1/fsqrt/fsincos/frndint/fscale/fsin/fcos */
           {
             ModRM m;
 
@@ -1984,7 +1992,8 @@ opcode_parse (const guint8  *image,
               }
           }
           return TRUE;
-        case 0xda:
+        case 0xda: /* fiadd/fimul/ficom/ficomp/fisub/fisubr/fidiv/fidivr
+                      fcmovb/fcmove/fcmovbe/fcmovu/fucompp */
           {
             ModRM m;
 
@@ -2017,7 +2026,8 @@ opcode_parse (const guint8  *image,
               }
           }
           return TRUE;
-        case 0xdb:
+        case 0xdb: /* fild/fist/fistp/fld/fstp/fnclex/fninit
+                      fcmovnb/fcmovne/fcmovnbe/fcmovnu/fucomi/fcomi */
           {
             ModRM m;
 
@@ -2054,7 +2064,7 @@ opcode_parse (const guint8  *image,
               }
           }
           return TRUE;
-        case 0xdc:
+        case 0xdc: /* fadd/fmul/fcom/fcomp/fsub/fsubr/fdiv/fdivr */
           {
             ModRM m;
 
@@ -2080,7 +2090,7 @@ opcode_parse (const guint8  *image,
               }
           }
           return TRUE;
-        case 0xdd:
+        case 0xdd: /* fld/fst/fstp/frstor/fnsave/fnstsw/ffree/fucomp */
           {
             ModRM m;
 
@@ -2111,7 +2121,8 @@ opcode_parse (const guint8  *image,
               }
           }
           return TRUE;
-        case 0xde:
+        case 0xde: /* fiadd/fimul/ficom/ficomp/fisub/fisubr/fidiv/fidivr
+                      faddp/fmulp/fsubrp/fsubp/fdivrp/fdivp */
           {
             ModRM m;
 
@@ -2143,7 +2154,7 @@ opcode_parse (const guint8  *image,
               }
           }
           return TRUE;
-        case 0xdf:
+        case 0xdf: /* fild/fist/fistp/fbld/fild/fbstp/fistp */
           {
             ModRM m;
 
@@ -2377,7 +2388,7 @@ opcode_parse (const guint8  *image,
                                     m.regop == 0 ? "inc" : "dec", m.regmem_s);
           }
           return TRUE;
-        case 0xff: /* inc/dec/call/jmp/push */
+        case 0xff: /* inc/dec/call/callf/jmp/push */
           {
             ModRM m;
 
